#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class quality(String, _HasAllowedValuesMixin):
    """
    Set the quality for raytracing. Higher quality leads to more refining of the raytraced image, which results in more time and memory consumption.
    """

    fluent_name = "quality"

